@@ -6,11 +6,16 @@ import unittest
 
 from test import testissues
 from test import testparsesource
+from test import testimports
 
 
 def main():
     testcases = (testissues.TestIssues,
+                 testimports.TestImports,
                  testparsesource.TestParseSource,
+                 testparsesource.TestSymbol,
+                 testparsesource.TestNonSymbol,
+                 testparsesource.TestMark,
                 )
     suite = unittest.TestSuite(map(unittest.makeSuite, testcases))
 
